@@ -214,8 +214,11 @@ BUILD_OPTIONS_CMDLINE = {
         'pr_descr',
         'pr_target_repo',
         'pr_title',
-        'rpath_filter',
         'regtest_output_dir',
+        'rpath_filter',
+        'rpath_override_dirs',
+        'banned_linked_shared_libs',
+        'required_linked_shared_libs',
         'silence_deprecation_warnings',
         'skip',
         'stop',
@@ -256,9 +259,11 @@ BUILD_OPTIONS_CMDLINE = {
         'rebuild',
         'robot',
         'rpath',
+        'sanity_check_only',
         'search_paths',
         'sequential',
         'set_gid_bit',
+        'skip_extensions',
         'skip_test_cases',
         'skip_test_step',
         'generate_devel_module',
@@ -341,7 +346,7 @@ BUILD_OPTIONS_OTHER = {
         'build_specs',
         'command_line',
         'external_modules_metadata',
-        'pr_path',
+        'pr_paths',
         'robot_path',
         'valid_module_classes',
         'valid_stops',
@@ -555,6 +560,18 @@ def build_option(key, **kwargs):
         raise EasyBuildError(error_msg)
 
 
+def update_build_option(key, value):
+    """
+    Update build option with specified name to given value.
+
+    WARNING: Use this with care, the build options are not expected to be changed during an EasyBuild session!
+    """
+    # BuildOptions() is a (singleton) frozen dict, so this is less straightforward that it seems...
+    build_options = BuildOptions()
+    build_options._FrozenDict__dict[key] = value
+    _log.warning("Build option '%s' was updated to: %s", key, build_option(key))
+
+
 def build_path():
     """
     Return the build path
